

from django.urls import path
from . import views
from django.conf.urls import include


urlpatterns = [
    path('', views.company, name='index'),
    path('delete', views.delete, name='delete'),
    path('edit', views.edit, name='edit'),
    path('add', views.add, name='add'),
    path('customer/', views.customer, name='customer'),
    path('customer/delete', views.customerdelete, name='customerdelete'),
    path('customer/edit', views.customeredit, name='customeredit'),
    path('customer/add', views.customeradd, name='customeradd'),
    

]





from django.db import models
from phonenumber_field.modelfields import PhoneNumberField


# Create your models here.

class Company(models.Model):
    name = models.CharField(max_length=300)
    img = models.ImageField(upload_to='company')
    address = models.TextField()



class Customer(models.Model):
    company = models.ForeignKey(Company, on_delete=models.CASCADE)
    name = models.CharField(max_length=100, unique = True, null = False, blank = False, default=None)
    email = models.EmailField(max_length=300, unique = True, null = False, blank = False, default=None)
    phoneNumber = PhoneNumberField(unique = True, null = False, blank = False, default=None)


import os
import sys
import platform

from django.core.management import execute_from_command_line




def main():
    if len(sys.argv) == 2:
        listen = sys.argv[1]
    else:
        listen = '127.0.0.1:8000'
    if platform.system() != 'Windows':
        sys.argv = [
            '',
            '-b',
            listen,
            'APTRS.wsgi:application',
            '--workers=1',
            '--threads=10',
            '--timeout=5600',
        ]
        from gunicorn.app.wsgiapp import run
        run()
    else:
        from waitress import serve
        from .APTRS import wsgi
        serve(
            wsgi.application,
            listen=listen,
            threads=10,
            channel_timeout=5600)


from django.shortcuts import render
from .models import Project, Vulnerability, Vulnerableinstance
from customers.models import Company, Customer
from vulnerability.models import VulnerabilityDB
from datetime import datetime
from django.http import HttpResponse
from django.contrib import messages
from django.http import JsonResponse, HttpResponseRedirect
from .forms import ProjectVulnerabilityForm
from django.views.decorators.csrf import csrf_exempt
import json
from django.contrib.auth.decorators import login_required
from io import BytesIO
from django.template.loader import get_template
from django.conf import settings
import os
import pdfkit
import PyPDF2
from PyPDF2 import PdfFileWriter
from accounts.models import Profile


@login_required
def project(request):

    project = Project.objects.all()
    return render(request, "Project/project.html",{'project': project})

@login_required
def projectadd(request):
    if request.method == 'GET':

        company = Company.objects.all().values('name')
        return render(request, "Project/projectadd.html", {'company': company})
        
    elif request.method == 'POST':
        company = request.POST['company']
        projectname = request.POST['projectname']
        projectdescription = request.POST['projectdescription']
        scope = request.POST['scope']
        projecttype = request.POST['projecttype']
        startname = request.POST['startname']
        enddate = request.POST['enddate']
        startname = datetime.strptime(startname, '%d/%m/%Y').strftime('%Y-%m-%d')
        enddate = datetime.strptime(enddate, '%d/%m/%Y').strftime('%Y-%m-%d')


        company = Company.objects.get(name=company)

        projectadd = Project(companyname=company,name=projectname, scope=scope, description=projectdescription,projecttype=projecttype,startdate=startname,enddate=enddate)
        projectadd.save()

        project = Project.objects.all()
        return render(request, "Project/project.html",{'project': project})



@login_required
def projectdelete(request, pk):
    Project.objects.get(pk=pk).delete()
    return HttpResponse(status=200)


@login_required
def projectView(request,pk):
    if request.method == 'GET':

        project =  Project.objects.get(pk=pk)
        vulnerability = Vulnerability.objects.filter(project=pk)
        
        return render(request, "Project/Project-Details.html", {'vulnerability': vulnerability, 'project': project})

@login_required
def projectedit(request,pk):
    if request.method == 'POST':
        projectname = request.POST['projectname']
        projectdescription = request.POST['projectdescription']
        scope = request.POST['scope']
        projecttype = request.POST['projecttype']
        startname = request.POST['startname']
        enddate = request.POST['enddate']


        startname = datetime.strptime(startname, '%d/%m/%Y').strftime('%Y-%m-%d')
        enddate = datetime.strptime(enddate, '%d/%m/%Y').strftime('%Y-%m-%d')
        
        project = Project.objects.get(pk=pk)
        project.name = projectname
        project.description = projectdescription
        project.scope = scope 
        project.projecttype = projecttype
        project.startdate = startname
        project.enddate = enddate
        project.save()
        messages.info(request,'Project Updated successfully')
        return HttpResponseRedirect('/project/'+pk+'/')

@login_required
def projectvulndelete(request,pk):
    Vulnerability.objects.get(pk=pk).delete()
    return HttpResponse(status=200)

@login_required
@csrf_exempt
def projectnewvuln(request,pk):
    form = ProjectVulnerabilityForm()
    if request.method == 'GET':
        vulnerabilityDB = VulnerabilityDB.objects.all().values('vulnerabilityname')
        context = {'form':form,'vulnerabilityDB': vulnerabilityDB,'project':pk}
        return render(request, "Project/newvulnerability.html", context)
    
    if request.method == 'POST':
        
        vulntitle = request.POST.get('vulnerabilityname')
        
        form = ProjectVulnerabilityForm(request.POST)
        
        if form.is_valid():
            
            responseid = form.save()
            responseData = {'Vulnerability': responseid.id,'Status':'Success','Project':pk}
            return JsonResponse(responseData)
        else:
            print(form.errors )
            #print(form.non_field_errors )




@login_required
def fetchvuln(request):
    vulntitle = request.GET['title']
    project =  VulnerabilityDB.objects.get(vulnerabilityname=vulntitle)
    print(project.vulnerabilityseverity)
    return JsonResponse({'severity':project.vulnerabilityseverity,'Description':project.vulnerabilitydescription,'solution':project.vulnerabilitysolution,'refer':project.vulnerabilityreferlnk,'vector':project.cvssvector})

@login_required
def projecteditvuln(request,pk):
    vlun = Vulnerability.objects.get(id=pk)
    form = ProjectVulnerabilityForm(instance=vlun)
    
    if request.method == 'POST':
        form = ProjectVulnerabilityForm(request.POST, instance=vlun)
        print(form.non_field_errors())
        if form.is_valid():
            form.save()
            project = vlun.project
        
            return HttpResponse(status=200)
        else:
            print(form.errors )
            print(form.non_field_errors )
       
    if request.method == 'GET':        
        vulnerabilityDB = VulnerabilityDB.objects.all().values('vulnerabilityname')
        instances = Vulnerableinstance.objects.filter(vulnerabilityid=pk)
        context = {'form':form,'vulnerabilityDB': vulnerabilityDB,'instances':instances,'id':pk}
        
        return render(request, 'Project/Edit-Vulnerability.html', context)

@login_required
@csrf_exempt
def deleteinstace(request,pk):
    #vulnid = request.POST['id']
    Vulnerableinstance.objects.get(pk=pk).delete()
    responseData = {'status':'success'}
    return JsonResponse(responseData)



        
@login_required
@csrf_exempt
def addurl(request,pk):
    body = json.loads(request.body)
    vulnerability = Vulnerability.objects.get(id=pk)
    for index in range(len(body)):
        url =body[index]['URL']
        paramter = body[index]['Paramter']
        print(url)
        print(paramter)
        vuln = Vulnerableinstance(URL=url,Paramter=paramter,vulnerabilityid=vulnerability,project=vulnerability.project)
        vuln.save()
    insntaceid = vuln.pk
    vlun = Vulnerability.objects.get(id=pk)
    project = vlun.project
    locationid = '/project/'+str(project.id)+'/'
    responseData = {'redirect':locationid,'insntaceid':insntaceid}
    return JsonResponse(responseData)






@login_required
def pdf(request,pk):
    project = Project.objects.get(pk=pk)

    order = ['Critical', 'High', 'Medium', 'Low', 'Informational']
    vuln = Vulnerability.objects.filter(project=project)
   
    instances = Vulnerableinstance.objects.filter(project=project)
    #print(request.user.profile.company)
   
    vuln = sorted(vuln, key=lambda x: order.index(x.vulnerabilityseverity))
    ciritcal =  Vulnerability.objects.filter(project=project,vulnerabilityseverity='Critical').count()
    high =  Vulnerability.objects.filter(project=project,vulnerabilityseverity='High').count()
    medium =  Vulnerability.objects.filter(project=project,vulnerabilityseverity='Medium').count()
    low =  Vulnerability.objects.filter(project=project,vulnerabilityseverity='Low').count()
    info =  Vulnerability.objects.filter(project=project,vulnerabilityseverity='Informational').count()
  
    customer = Customer.objects.filter(company=project.companyname)
    profile = Profile.objects.all()
    userid = request.user.id
    userdetails = Profile.objects.get(user=userid)
    #print(userdetails.company)
   
    tocstyle = (os.path.join(settings.BASE_DIR,'templates','Report','toc.xml'))
    url = request.build_absolute_uri()
    
    
    
    template = get_template('Report/Report.html')
    footerpage = (os.path.join(settings.BASE_DIR,'templates','Report','Footer.html'))
    content = {'vuln':vuln,'project':project,"settings":settings} 
    
    cover = get_template('Report/cover.html')
    bgimage = (os.path.join(settings.BASE_DIR,'assets','images','BG.jpg'))
    coverpage = cover.render({'project':project,"settings":settings,'bgimage':bgimage})
    
    
    pdfpage = template.render({'vuln':vuln,'project':project,"settings":settings,"url":url,'userdetails':userdetails,'profile':profile,'customer':customer,'ciritcal':ciritcal,'high':high,'medium':medium,'low':low,'info':info,'instances':instances})
    pdfpageoptions = {'javascript-delay':'800','margin-left': '0','margin-right': '0','margin-top': '10','margin-bottom': '7','enable-local-file-access': '','footer-font-name':'Segoe UI','enable-javascript':'','footer-html':footerpage}
    pdfpagepdf = pdfkit.from_string(pdfpage,"reportpage.pdf",pdfpageoptions,cover = coverpage,cover_first=True,toc={"toc-header-text": "Table of Contents",'xsl-style-sheet':tocstyle,'disable-dotted-lines':''})
    
    

   
    options = {'margin-left': '0','margin-right': '0','margin-top': '0','margin-bottom': '0','enable-local-file-access': '','footer-font-name':'Segoe UI','enable-javascript':''}
    pdf = pdfkit.from_string(coverpage, 'coverpage.pdf',options)
    


    pdfWriter = PyPDF2.PdfFileWriter()
    pdf1Reader = PyPDF2.PdfReader('coverpage.pdf')
    pdf2Reader = PyPDF2.PdfReader('reportpage.pdf')
    #print(pdf1Reader)
    pageObj = pdf1Reader.getPage(0)
    pdfWriter.addPage(pageObj)
    for pageNum in range(pdf2Reader.numPages):
        if not pageNum == 0:
            pageObj = pdf2Reader.getPage(pageNum)
       
            pdfWriter.addPage(pageObj)
    response_bytes_stream = BytesIO()
    pdfWriter.write(response_bytes_stream)
    os.remove('coverpage.pdf')
    os.remove('reportpage.pdf')
    filename = project.projecttype + " Report of " + project.name+".pdf"
    response = HttpResponse(response_bytes_stream.getvalue(), content_type='application/pdf')
    response['Content-Disposition'] = f'inline; filename={filename}'

    return response 


from django.db import models
from django.contrib.auth.models import User


# Create your models here.


class Profile(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE,related_name='userprofile',null=True)
    profilepic = models.ImageField(default='profile/avatar-1.jpg', upload_to='profile')
    number =models.IntegerField()
    company = models.CharField(max_length=300)

    
    def __str__(self):
        return self.user.username
    



from django.shortcuts import render
from django.contrib.auth import authenticate, login,logout
from django.http import HttpResponseRedirect
from django.contrib.auth.models import User
from django.contrib.auth.decorators import login_required
from .forms import UpdateUserForm, UpdateProfileForm
from .models import Profile

from django.http import HttpResponse, JsonResponse
# Create your views here.


def Login(request):
    if request.method == 'GET':
        return render(request, "Accounts/login.html")
    
    elif request.method == 'POST':
        username = request.POST['username']
        password = request.POST['password']
        user = authenticate(request, username = username, password = password)
        if user is not None:
            login(request, user)
            return HttpResponseRedirect('/')
    

@login_required
def Logout(request):
    logout(request)
    return HttpResponseRedirect('/accounts/login')


@login_required
def profile(request,pk):
    user = User.objects.get(pk=pk)
    profile = Profile.objects.get(user=pk)
    
    user_form = UpdateUserForm(instance=user)
    
    profile_form = UpdateProfileForm(instance=profile)
    if request.method == 'POST':
        
        user_form = UpdateUserForm(request.POST, instance=user)
        profile_form = UpdateProfileForm(request.POST, request.FILES, instance=profile)
        username = request.POST['username']
        email = request.POST['email']
        number = request.POST['number']
        
        if User.objects.exclude(pk=pk).filter(username=username).exists():
            
            responseData = {'Userexist': 'True'}
            return JsonResponse(responseData)
        elif User.objects.exclude(pk=pk).filter(email=email).exists():
            
            responseData = {'Emailexist': 'True'}
            return JsonResponse(responseData)
        elif Profile.objects.exclude(user=pk).filter(number=number).exists():
            
            responseData = {'number': 'True'}
            return JsonResponse(responseData)
        else:
            

            if user_form.is_valid() and profile_form.is_valid():
                user_form.save()
                profile_form.save()
                responseData = {'Status': 'Success'}
                return JsonResponse(responseData)
            else:
                responseData = {'Status': 'Fail'}
                return JsonResponse(responseData)

    
    if request.method == 'GET':
        userdetails = User.objects.get(pk=pk)
        context = {'userform':user_form,'profileform': profile_form,'profile':profile}
        return render(request, "Accounts/profile.html",context)
    





@login_required
def setting(request):
    if request.method == 'GET':
        user = User.objects.all()
        profile = Profile.objects.all()
        context = {"user":user,"profile":profile}
        return render(request, "Accounts/setting.html",context)


@login_required
def Delete(request,pk):
    
    User.objects.get(pk=pk).delete()
    return HttpResponse(status=200)
    

@login_required
def add(request):
    if request.method == 'GET':
        profile_form = UpdateProfileForm()
        context = {'profileform': profile_form}
        
        return render(request, "Accounts/add-user.html",context)


    if request.method == 'POST':

        user_form = UpdateUserForm(request.POST)

        username = request.POST['username']
        email = request.POST['email']
        number = request.POST['number']
        fname = request.POST['first_name']
        lname = request.POST['last_name']
        password = request.POST['password']
        company = request.POST['company']
        
        if User.objects.filter(username=username).exists():
            
            responseData = {'Userexist': 'True'}
            return JsonResponse(responseData)
        elif User.objects.filter(email=email).exists():
            
            responseData = {'Emailexist': 'True'}
            return JsonResponse(responseData)
        elif Profile.objects.filter(number=number).exists():
            
            responseData = {'number': 'True'}
            return JsonResponse(responseData)
        
        else:
            usersave = User(username=username,email=email,first_name=fname,last_name=lname)
            usersave.set_password(password)
            usersave.save()
            profile_form = UpdateProfileForm(request.POST, request.FILES)
           
            profile_form.user = usersave.id
            if profile_form.is_valid():
                
                formdata = profile_form.save()
                profileid = formdata.pk
                print(profileid)
                profiledata = Profile.objects.get(pk=profileid)
                profiledata.user_id = usersave.id
                profiledata.save()
                responseData = {'Status': 'Success'}
                return JsonResponse(responseData)
            else:
                responseData = {'Status': 'Fail'}
                return JsonResponse(responseData)





"""APTRS URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, include,re_path
from django.conf import settings
from django.conf.urls.static import static,serve


urlpatterns = [
    path('',include('project.urls')),
    path('company/',include('customers.urls')),
    path('vulnerability/',include('vulnerability.urls')),
    #path('admin/', admin.site.urls),
    path('ckeditor/', include('ckeditor_uploader.urls')),
    path('accounts/',include('accounts.urls')),
    re_path(r'^media/(?P<path>.*)$', serve, {'document_root': settings.MEDIA_ROOT,}),
    re_path(r'^static/(?P<path>.*)$', serve, {'document_root': settings.STATIC_ROOT,}),
]




#urlpatterns = urlpatterns + static('/media/', document_root = settings.MEDIA_ROOT)
#urlpatterns = urlpatterns + static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)



from django.db import models
#from ckeditor.fields import RichTextField

from ckeditor_uploader.fields import RichTextUploadingField

# Create your models here.



class VulnerabilityDB(models.Model):
    vulnerabilityname = models.CharField(max_length=300)
    vulnerabilityseverity = models.CharField(max_length=300)
    vulnerabilitydescription = RichTextUploadingField()
    vulnerabilitysolution = RichTextUploadingField()
    vulnerabilityreferlnk = RichTextUploadingField(blank=True,null=True)
    cvssscore = models.FloatField(blank=True,null=True)
    cvssvector = models.CharField(max_length=300,default=None,null=True)






from django.db import models
from customers.models import Company, Customer
from ckeditor_uploader.fields import RichTextUploadingField
from django.utils import timezone

# Create your models here.


class Project(models.Model):
    name = models.CharField(max_length=100, unique = False, null = False, blank = False, default=None)
    companyname = models.ForeignKey(Company, on_delete=models.CASCADE)
    scope = models.CharField(max_length=100, unique = False, null = False, blank = False, default=None)
    description = models.CharField(max_length=100, unique = False, null = False, blank = False, default=None)
    projecttype = models.CharField(max_length=100, unique = False, null = False, blank = False, default=None)
    startdate = models.DateField()
    enddate = models.DateField()

class Vulnerability(models.Model):
    project = models.ForeignKey(Project, on_delete=models.CASCADE)
    vulnerabilityname = models.CharField(max_length=300,default=None,blank=True,null=True)
    vulnerabilityseverity = models.CharField(max_length=300,null=True)
    cvssscore = models.FloatField(blank=True,null=True)
    cvssvector = models.CharField(max_length=300,default=None,null=True)
    status = models.CharField(max_length=300,null=True)
    vulnerabilitydescription = RichTextUploadingField(blank=True,null=True)
    POC = RichTextUploadingField(default=None,blank=True,null=True)
    created = models.DateTimeField(editable=False,default=None, null=True)
    vulnerabilitysolution = RichTextUploadingField(blank=True,null=True)
    vulnerabilityreferlnk = RichTextUploadingField(blank=True,null=True)
    #vulnerableurl =  models.CharField(max_length=1000,default=None,blank=True,null=True)


class Vulnerableinstance(models.Model):
    vulnerabilityid = models.ForeignKey(Vulnerability, on_delete=models.CASCADE)
    project = models.ForeignKey(Project, on_delete=models.CASCADE,blank=True,null=True)
    URL = models.CharField(max_length=1000,default=None,blank=True,null=True)
    Paramter = models.CharField(max_length=1000,default=None,blank=True,null=True)



from django.contrib import admin
from .models import Project,Vulnerability, Vulnerableinstance
# Register your models here.



admin.site.register(Project)
admin.site.register(Vulnerability)
admin.site.register(Vulnerableinstance)


"""
Django settings for APTRS project.

Generated by 'django-admin startproject' using Django 4.1.

For more information on this file, see
https://docs.djangoproject.com/en/4.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/4.1/ref/settings/
"""

from pathlib import Path
import os
import logging

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent

logging.disable(logging.CRITICAL)
ADMIN_ENABLED = False

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/4.1/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'django-insecure--b83(+esj0aubo_gr!f*k)tyvs*_t_&4e2ty00beroxof8@d!7'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = False

ALLOWED_HOSTS = ['*']


# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'accounts',
    'customers',
    'phonenumber_field',
    'vulnerability',
    'ckeditor',
    'ckeditor_uploader',
    'project',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'APTRS.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(BASE_DIR,'templates')],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'APTRS.wsgi.application'


# Database
# https://docs.djangoproject.com/en/4.1/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': BASE_DIR / 'db.sqlite3',
    }
}


# Password validation
# https://docs.djangoproject.com/en/4.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/4.1/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/4.1/howto/static-files/



STATIC_URL = 'static/'
#STATICFILES_DIRS = [    os.path.join(BASE_DIR, 'static')]

STATIC_ROOT = os.path.join(BASE_DIR, 'static')

# Default primary key field type
# https://docs.djangoproject.com/en/4.1/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'
#STATICFILES_STORAGE = 'whitenoise.storage.CompressedStaticFilesStorage'

MEDIA_URL = '/media/'
#MEDIA_URL2 = '/media/'
MEDIA_PATH = os.path.join(BASE_DIR, 'static')
MEDIA_ROOT = os.path.join(MEDIA_PATH, 'media')
Company_LOGO = os.path.join(MEDIA_URL, 'company')

CKEDITOR_UPLOAD_PATH = "uploads/"
CKEDITOR_CONFIGS = {
    'default': {
        'skin': 'moono-dark',
        # 'skin': 'office2013',
        'toolbar_Basic': [
            ['Source', '-', 'Bold', 'Italic']
        ],
        'toolbar_YourCustomToolbarConfig': [
          
            
           
            
            
            {'name': 'basicstyles',
             'items': ['Bold', 'Italic', 'Underline', 'Strike', 'Subscript', 'Superscript', '-', 'RemoveFormat']},
            {'name': 'paragraph',
             'items': ['NumberedList', 'BulletedList', '-', 'Outdent', 'Indent', '-', 'Blockquote', 'CreateDiv', '-',
                       'JustifyLeft', 'JustifyCenter', 'JustifyRight', 'JustifyBlock', '-', 'BidiLtr', 'BidiRtl']},
                       
            {'name': 'links', 'items': ['Link', 'Unlink', 'Anchor']},
            '/',
            {'name': 'insert',
             'items': ['Image','Image2','Codesnippet','Uploadwidget', 'HorizontalRule']},
           
            {'name': 'styles', 'items': ['Styles', 'Format', 'Font', 'FontSize']},
            {'name': 'colors', 'items': ['TextColor', 'BGColor']},
            
            
        ],
        'toolbar': 'YourCustomToolbarConfig',  # put selected toolbar config here
        # 'toolbarGroups': [{ 'name': 'document', 'groups': [ 'mode', 'document', 'doctools' ] }],
        # 'height': 291,
        # 'width': '100%',
        # 'filebrowserWindowHeight': 725,
        # 'filebrowserWindowWidth': 940,
        # 'toolbarCanCollapse': True,
        # 'mathJaxLib': '//cdn.mathjax.org/mathjax/2.2-latest/MathJax.js?config=TeX-AMS_HTML',
        'tabSpaces': 4,
        'extraPlugins': ','.join([
            'uploadimage', # the upload image feature
            # your extra plugins here
            'div',
            'autolink',
            'autoembed',
            'embedsemantic',
            'autogrow',
            # 'devtools',
            'widget',
            'lineutils',
            'clipboard',
            'codesnippet',
            'image2',
            'uploadwidget',
            'elementspath'
        ]),
    }
}

CKEDITOR_ALLOW_NONIMAGE_FILES = False

WKHTMLTOPDF_CMD_OPTIONS = {'disable-javascript': True}

LOGIN_URL= '/accounts/login'



from django import forms

from django.contrib.auth.models import User
from .models import Profile


class UpdateUserForm(forms.ModelForm):
    username = forms.CharField(max_length=100,required=True,widget=forms.TextInput())
    email = forms.EmailField(required=True,widget=forms.TextInput())
    first_name = forms.CharField(max_length=100,required=True,widget=forms.TextInput())
    last_name = forms.CharField(max_length=100,required=True,widget=forms.TextInput())

    class Meta:
        model = User
        fields = ['username', 'email','first_name','last_name']



class UpdateProfileForm(forms.ModelForm):
    profilepic = forms.ImageField(widget=forms.FileInput(attrs={'class': 'form-control fileupload'}))
    number = forms.IntegerField(required=True,widget=forms.TextInput())
    company = forms.CharField(max_length=100,required=True,widget=forms.TextInput())

    class Meta:
        model = Profile
        fields = ['profilepic', 'number','company']


from django.shortcuts import render
from .models import VulnerabilityDB
from django.contrib.auth.decorators import login_required
from .forms import VulnerabilityDBForm
from django.http import HttpResponseRedirect
from django.http import HttpResponse

# Create your views here.
from django.http import JsonResponse




@login_required
def vulerabilitiydb(request):

    vulnerability = VulnerabilityDB.objects.all()
    return render(request, "Vulnerability-Database/vulerabilitiydb.html", {'vulnerability': vulnerability})
    

@login_required
def vulerabilitiydbadd(request):
    form = VulnerabilityDBForm()
    if request.method == 'POST':
        form = VulnerabilityDBForm(request.POST)
        if form.is_valid():
            form.save()
            return HttpResponse(status=200)
            
        else:
            return HttpResponse(status=500)
            print(form.errors )
            print(form.non_field_errors )
       

    if request.method == 'GET':
        context = {'form':form}
        return render(request, "Vulnerability-Database/vulerabilitiydbadd.html", context)

   
@login_required
def vulerabilitiydbedit(request, pk):
    vlun = VulnerabilityDB.objects.get(id=pk)
    form = VulnerabilityDBForm(instance=vlun)
    
    if request.method == 'POST':
        form = VulnerabilityDBForm(request.POST, instance=vlun)
        if form.is_valid():
            form.save()
            responseData = {'Status':'Success'}
            return JsonResponse(responseData)
        else:
            responseData = {'Status':'Fail'}
            return JsonResponse(responseData)
            
    context = {'form':form}
    return render(request, 'Vulnerability-Database/vulerabilitiydbedit.html', context)
    
@login_required
def vulerabilitiydbdelete(request, pk):
    VulnerabilityDB.objects.get(pk=pk).delete()
    return HttpResponse(status=200)




from django.urls import path
from . import views
from django.conf.urls import include




urlpatterns = [
    path('', views.project, name='index'),
    path('project/add', views.projectadd, name='projectadd'),
    path('project/delete/<str:pk>/', views.projectdelete, name='projectdelete'),
    path('project/<str:pk>/', views.projectView, name='projectView'),
    path('project/edit/<str:pk>/', views.projectedit, name='projectedit'),
    path('project/vulnerability/delete/<str:pk>/', views.projectvulndelete, name='projectvulndelete'),
    path('project/newvulnerability/<str:pk>/', views.projectnewvuln, name='projectnewvuln'),
    path('project/fetch/vulnerability', views.fetchvuln, name='fetchvuln'),
    path('project/editvulnerability/<str:pk>/', views.projecteditvuln, name='projecteditvuln'),
    path('project/report/addurl/<str:pk>/', views.addurl, name='addurl'),
    path('project/delete/instace/<str:pk>/', views.deleteinstace, name='deleteinstace'),
    path('project/report/pdf/<str:pk>/', views.pdf),
                                           
    

    

]





from django.urls import path
from . import views

urlpatterns = [
    path('', views.vulerabilitiydb, name='index'),
    path('add', views.vulerabilitiydbadd, name='add'),
    path('edit/<str:pk>/', views.vulerabilitiydbedit, name='edit'),
    path('delete/<str:pk>/', views.vulerabilitiydbdelete, name='edit'),
    
]




"""
WSGI config for APTRS project.

It exposes the WSGI callable as a module-level variable named ``application``.

For more information on this file, see
https://docs.djangoproject.com/en/4.1/howto/deployment/wsgi/
"""

import os
import warnings
from . import settings
from django.core.wsgi import get_wsgi_application





os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'APTRS.settings')

application = get_wsgi_application()





from django.urls import path
from . import views

urlpatterns = [
    path('login', views.Login, name='login'),
    path('logout', views.Logout, name='logout'),
    path('profile/<str:pk>/', views.profile, name='profile'),
    path('setting', views.setting, name='setting'),
    path('delete/<str:pk>/', views.Delete, name='delete'),
    path('add', views.add, name='add'),
    
]




#!/usr/bin/env python3

from setuptools import (
    find_packages,
    setup,
)

from pathlib import Path


def read(rel_path):
    init = Path(__file__).resolve().parent / rel_path
    return init.read_text('utf-8', 'ignore')



description = (
    'Automated Penetration Testing Reporting System')

setup(
    name='aptrs',
    version='0.0.1b',
    description=description,
    author='AnoF',
    author_email='kalalsourav20@gmail.com',
    packages=find_packages(include=[
        '*', 'aptrs.*',
    ]),
    include_package_data=True,
    python_requires='>=3.8+',
    entry_points={
        'console_scripts': [
            'aptrs = APTRS.__main__:main',
        ],
    },
    url='https://github.com/Anof-cyber/APTRS',
    long_description=read('README.md'),
    long_description_content_type='text/markdown',
    install_requires=Path('requirements.txt').read_text().splitlines(),
)


from django.shortcuts import render
from .models import Company, Customer
from django.core.exceptions import ObjectDoesNotExist
from django.http import JsonResponse, HttpResponseRedirect
from django.core.files.storage import FileSystemStorage
from django.conf import settings
import os
from django.contrib import messages
from django.http import HttpResponse

from django.contrib.auth.decorators import login_required

# Create your views here.

@login_required
def company(request):

    company = Company.objects.all()
    return render(request, "Company/Company.html", {'company': company})

@login_required
def delete(request):
    if request.method =='GET':
        companyid = request.GET['companyid']
        try:

            
            Company.objects.get(pk=companyid).delete()
            return HttpResponse(status=200)
            
            #responseData = {'status': 'Success'}

            #return JsonResponse(responseData)
        except ObjectDoesNotExist:
            responseData = {'status': 'Fail'}
            return JsonResponse(responseData)



@login_required
def edit(request):
    if request.method == 'GET':
        company = request.GET['company']

        try:
            company = Company.objects.get(pk=company)
            return render(request, "Company/EditCompany.html", {'company': company})
        except ObjectDoesNotExist:
            responseData = {'status': 'Fail to retrive data'}
            return JsonResponse(responseData)
    
    elif request.method =='POST':
        company = request.POST['company']
        name = request.POST['name']
        address = request.POST['address']
        print(type(company))
        if company == "":
            responseData = {'status': 'Fail to update data'}
            return JsonResponse(responseData)
        else:
            try:
                companyobject = Company.objects.get(pk=company)
                companyobject.name = name
                companyobject.address = address
                companyobject.save()

                if 'image' in request.FILES:
                    upload = request.FILES['image']
                    path = os.path.join(settings.MEDIA_ROOT, 'company')
                    
                    fss = FileSystemStorage(location=path, base_url=path)
                    file = fss.save(upload.name, upload)
                    file_url = fss.url(file)

                    
                    companyobject.img = os.path.join('company', file_url)
                    companyobject.save()
                messages.info(request,'Company Updated successfully')
      
                return HttpResponseRedirect(request.path_info + "?company="+ company)
                #return HttpResponseRedirect(request.path_info + "?company="+ company)
                    

                

            except ObjectDoesNotExist:
                responseData = {'status': 'Fail to update data'}
                return JsonResponse(responseData)




@login_required
def add(request):
    if request.method == 'GET':
        return render(request, "Company/AddCompany.html")

    elif request.method =='POST':
        name = request.POST['name']
        address = request.POST['address']
        customer = Company(name=name,address=address)
        customer.save()
        if 'image' in request.FILES:
            upload = request.FILES['image']
            path = os.path.join(settings.MEDIA_ROOT, 'company')
                    
            fss = FileSystemStorage(location=path, base_url=path)
            file = fss.save(upload.name, upload)
            file_url = fss.url(file)
            customer.img =  os.path.join('company', file_url)
            customer.save()
        company = Company.objects.all()
        return render(request, "Company/Company.html", {'company': company})



@login_required
def customer(request):

    customer = Customer.objects.all()
    return render(request, "Customer/Customer.html", {'customer': customer})


@login_required
def customerdelete(request):
    if request.method =='GET':
        customerid = request.GET['customerid']
        try:
            Customer.objects.get(pk=customerid).delete()
            return HttpResponse(status=200)

        except ObjectDoesNotExist:
            responseData = {'status': 'Fail'}
            return JsonResponse(responseData)

@login_required
def customeredit(request):
    if request.method == 'GET':
        customer = request.GET['customer']

        try:
            customer = Customer.objects.get(pk=customer)
            company = Company.objects.all().values('name')
            return render(request, "Customer/EditCustomer.html", {'customer': customer, 'company': company})
        except ObjectDoesNotExist:
            responseData = {'status': 'Fail to retrive data'}
            return JsonResponse(responseData)

    elif request.method =='POST':

        company = request.POST['company']
        customername = request.POST['name']
        email = request.POST['email']
        number = request.POST['Number']
        customer = request.POST['customer']
        

        company = Company.objects.get(name=company)

        customerobject = Customer.objects.get(pk=customer)
        customerobject.company = company
        customerobject.name = customername
        customerobject.email = email 
        customerobject.phoneNumber = number
        customerobject.save()
        messages.info(request,'Customer Updated successfully')
        #return HttpResponseRedirect(request.path_info)
        return HttpResponseRedirect(request.path_info + "?customer="+ customer)


@login_required
def customeradd(request):
    if request.method == 'GET':
        company = Company.objects.all().values('name')
        return render(request, "Customer/AddCustomer.html", {'company': company})

    elif request.method =='POST':

        company = request.POST['company']
        customername = request.POST['name']
        email = request.POST['email']
        number = request.POST['Number']
        
        company = Company.objects.get(name=company)


        customeradd = Customer(company=company,name=customername, email=email, phoneNumber=number)
        customeradd.save()

        customer = Customer.objects.all()
        
        return render(request, "Customer/Customer.html", {'customer': customer})